@@ -1,8 +1,8 @@
 #!/bin/sh
-# $Id: c_smrrds.sh,v 1.26 2004/02/26 22:48:08 dijkstra Exp $
+# $Id: c_smrrds.sh,v 1.30 2005/03/20 16:17:22 dijkstra Exp $
 
 #
-# Copyright (c) 2001-2004 Willem Dijkstra
+# Copyright (c) 2001-2005 Willem Dijkstra
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -32,7 +32,7 @@
 # --- user configuration starts here
 INTERVAL=${INTERVAL:-5}
 # --- user configuration ends here
-
+OS=`uname -s`
 # addsuffix adds a suffix to each entry of a list (item|item|...)
 addsuffix() {
     list=$1'|'
@@ -73,7 +73,7 @@ oneday)
     RRA_SETUP=" RRA:AVERAGE:0.5:1:17280
 	    RRA:MAX:0.5:1:17280
 	    RRA:MIN:0.5:1:17280"
-    if [ X"$child" == "X" ]; then
+    if [ X"$child" = "X" ]; then
 	echo "RRDs will only contain a single day of data"
     fi
     ;;
@@ -88,7 +88,7 @@ oneday)
 esac
 done
 
-if [ X"$RRA_SETUP" == "X" ]; then
+if [ X"$RRA_SETUP" = "X" ]; then
 # default RRA setup:
 # - 2   days of  5 second  samples = 34560 x 5 second samples
 # - 14  days of 30 minutes samples = 672 x 360 x 5 second samples
@@ -109,21 +109,47 @@ RRA_SETUP=" RRA:AVERAGE:0.5:1:34560
 fi
 
 # All interfaces and disks
-INTERFACES="an|awi|be|bge|bm|cnw|dc|de|ec|ef|eg|el|em|ep|ex|fea|fpa|fxp|gem|gm|gre|hme|ie|kue|lc|le|lge|lmc|lo|ne|nge|ray|rl|qe|sf|sis|sk|sl|sm|ste|stge|ti|tl|tr|tx|txp|vme|vr|wb|we|wi|wx|xe|xl"
-VIRTUALINTERFACES="bridge|carp|enc|faith|gif|ppp|sppp|strip|tun|vlan";
-DISKS="sd|cd|ch|rd|raid|ss|uk|vnc|wd"
-
+case ${OS} in
+FreeBSD)
+	DISKS="ad|acd|afd|ast|sa|da|ar|cd|ch|md"
+	INTERFACES="an|ar|ath|aue|awi|axe|bfe|bge|cm|cnw|cs|cue|dc|de|ed|el|em|ep|ex|fe|fwe|fxp|gem|gx|hme|ie|kue|lge|lnc|my|nge|pcn|ray|re|rl|rue|sf|sis|sk|sn|snc|ste|ti|tl|tx|txp|vge|vr|vx|wb|wi|xe|xl";
+	VIRTUALINTERFACES="bridge|carp|enc|faith|gif|ppp|sl|sppp|strip|tun|vlan";
+	diskcmd="mount | sed -n '/^\/dev/ s,/dev/\([a-z]*[0-9]\).*,\1,p' | sort -u"
+	interfacecmd="ifconfig -l | sed 's/lo0//'"
+	;;
+Linux)
+	DISKS="hda|hdb|hdc|hdd|sda|sdb|sdc|sdd"
+	INTERFACES="eth"
+	VIRTUALINTERFACES="sit"
+	diskcmd="mount | sed -n '/^\/dev/ s,/dev/\([a-z]*[0-9]\).*,\1,p' | sort -u"
+	interfacecmd="ifconfig -a| egrep -e \"^(\$INTERFACES) \" | cut -f1 -d\  | sort -u"
+	;;
+OpenBSD)
+	DISKS="sd|cd|ch|rd|raid|ss|uk|vnc|wd"
+	INTERFACES="an|awi|be|bge|bm|cnw|dc|de|ec|ef|eg|el|em|ep|ex|fea|fpa|fxp|gem|gm|gre|hme|ie|kue|lc|le|lge|lmc|lo|ne|nge|ray|rl|qe|sf|sis|sk|sl|sm|ste|stge|ti|tl|tr|tx|txp|vme|vr|wb|we|wi|wx|xe|xl"
+	VIRTUALINTERFACES="bridge|carp|enc|faith|gif|ppp|sppp|strip|tun|vlan";
+	diskcmd="mount | sed -n '/^\/dev/ s,/dev/\([a-z]*[0-9]\).*,\1,p' | sort -u"
+	interfacecmd="ifconfig -a| egrep -e \"^(\$INTERFACES):\" | cut -f1 -d\:  | sort -u"
+	;;
+NetBSD)
+	DISKS="sd|cd|ch|rd|raid|ss|uk|vnc|wd"
+	INTERFACES="ai|an|ate|ath|atw|awi|bce|bge|bicc|cnw|com|cs|depca|ec|ef|eg|el|elmc|en|ep|epic|esh|ex|fea|fmv|fpa|fxp|gsip|hme|ipw|iwi|ix|iy|lc|le|lmc|mbe|mhzc|mtd|ne|nele|ntwoc|pcn|ray|re|rtk|sf|sip|sk|skc|sm|ste|stge|ti|tl|tlp|tr|vge|vr|we|wi|wm|xi|xirc"
+	VIRTUALINTERFACES="bridge|carp|enc|faith|gif|ppp|sppp|sl|strip|tun|vlan";
+	diskcmd="mount | sed -n '/^\/dev/ s,/dev/\([a-z]*[0-9]\).*,\1,p' | sort -u"
+	interfacecmd="ifconfig -l | sed 's/lo0//'"
+	;;
+esac
 DISKS=`addsuffix $DISKS [0-9]`
 INTERFACES=`addsuffix $INTERFACES [0-9]`
 VIRTUALINTERFACES=`addsuffix $VIRTUALINTERFACES \\.\\*`
 
 this=$0
-if [ X"$1$2$3$4$5$6$7$8$9" == "X" ]; then
+if [ X"$1$2$3$4$5$6$7$8$9" = "X" ]; then
     cat <<EOF
 Create rrd files for symux.
 
-Usage: $0 [oneday] [interval <seconds>] all | cpu0 | mem |
-		   pf | mbuf | debug | proc_<process> |
+Usage: `basename $0` [oneday] [interval <seconds>] all | cpu0 | mem |
+		   pf | pfq_<queue> | mbuf | debug | proc_<process> |
 		   <if> | <io> | sensor[0-25]
 
 Where:
@@ -131,6 +157,8 @@ oneday  = modify rrds to only contain one day of information
 seconds = modify rrds for non standard monitoring interval
 process = the name of a process as specified in sy{mon,mux}.conf
 	  e.g. proc(httpd) -> proc_httpd
+queue = the name of a queue as specified in sy{mon,mux}.conf
+	  e.g. pfq(root) -> pfq_root
 
 if=	`echo $INTERFACES|
    awk 'BEGIN  {FS="|"}
@@ -151,7 +179,7 @@ io=	`echo $DISKS|
 		}
 		print " ";}'`
 
-Pre 3.5 disk statistics are available via the io1_<disk> argument.
+OpenBSD pre-3.5 disk statistics are available via the io1_<disk> argument.
 EOF
     exit 1;
 fi
@@ -164,7 +192,7 @@ if [ `echo $i | egrep -e "^($VIRTUALINTERFACES)$"` ]; then i=if_$i.rrd; fi
 # add io_*.rrd if it is a disk
 if [ `echo $i | egrep -e "^($DISKS)$"` ]; then i=io_$i.rrd; fi
 # add .rrd if it is a cpu, etc.
-if [ `echo $i | egrep -e "^(cpu[0-9]$|mem$|pf$|mbuf$|debug$|proc_|sensor[0-9]$|sensor[0-9][0-9]$|io1_)"` ]; then i=$i.rrd; fi
+if [ `echo $i | egrep -e "^(cpu[0-9]$|mem$|pf$|pfq_|mbuf$|debug$|proc_|sensor[0-9]$|sensor[0-9][0-9]$|io1_)"` ]; then i=$i.rrd; fi
 
 if [ -f $i ]; then
     echo "$i exists - ignoring"
@@ -186,12 +214,12 @@ all)
 
 if|interfaces)
     # obtain all network cards
-    sh $this child $config `ifconfig -a| egrep -e "^($INTERFACES):" | cut -f1 -d\:  | sort -u`
+    sh $this child $config `eval $interfacecmd`
     ;;
 
 io|disks)
     # obtain all disks
-    sh $this child $config `df | grep dev | sed 's/^\/dev\/\(.*\)[a-z] .*$/\1/' | sort -u`
+    sh $this child $config `eval $diskcmd`
     ;;
 
 cpu[0-9].rrd)
@@ -262,7 +290,7 @@ pf.rrd)
 	DS:packets_v4_out_pass:DERIVE:$INTERVAL:0:U DS:packets_v4_out_drop:DERIVE:$INTERVAL:0:U \
 	DS:packets_v6_in_pass:DERIVE:$INTERVAL:0:U DS:packets_v6_in_drop:DERIVE:$INTERVAL:0:U \
 	DS:packets_v6_out_pass:DERIVE:$INTERVAL:0:U DS:packets_v6_out_drop:DERIVE:$INTERVAL:0:U \
-	DS:states_entries:ABSOLUTE:$INTERVAL:0:U \
+	DS:states_entries:GAUGE:$INTERVAL:0:U \
 	DS:states_searches:DERIVE:$INTERVAL:0:U \
 	DS:states_inserts:DERIVE:$INTERVAL:0:U \
 	DS:states_removals:DERIVE:$INTERVAL:0:U \
@@ -274,6 +302,15 @@ pf.rrd)
 	DS:counters_memory:DERIVE:$INTERVAL:0:U
     ;;
 
+pfq_*.rrd)
+	# Build pfq file
+	create_rrd $i \
+	    DS:sent_bytes:COUNTER:$INTERVAL:0:U \
+	    DS:sent_packets:COUNTER:$INTERVAL:0:U \
+	    DS:drop_bytes:COUNTER:$INTERVAL:0:U \
+	    DS:drop_packets:COUNTER:$INTERVAL:0:U
+	;;
+
 mbuf.rrd)
     # Build mbuf file
     create_rrd $i \
